Skip to contents

List allocation mode types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

allocation_mode_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 4 rows and 3 columns.

Examples

head(entsoeapi::allocation_mode_types)
#> # A tibble: 4 × 3
#>   code  title                                         description                                                       
#>   <chr> <chr>                                         <chr>                                                             
#> 1 A01   Order by price with pro rata                  The allocation method is by price with eventual pro rata.         
#> 2 A02   Order by price with first come - first served The allocation method is by price with eventual use of first come…
#> 3 A03   First come - First served                     The allocation method is first come first served.                 
#> 4 A04   Pro rata                                      The allocation method is pro rata.