Skip to contents

List analog types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

analog_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 42 rows and 3 columns.

Examples

head(entsoeapi::analog_types)
#> # A tibble: 6 × 3
#>   code  title                                          description                                                      
#>   <chr> <chr>                                          <chr>                                                            
#> 1 A01   Flow                                           "This is the computed flow for the monitored element in the cons…
#> 2 A02   Permanent admissible transmission limit (PATL) "The permanent load of transmission system elements which is all…
#> 3 A03   Flow reliability margin                        "This is the flow reliability margin for a given critical networ…
#> 4 A04   Spanning margin value                          "This is the margin that is taken into account when spanning (fa…
#> 5 A05   Long term allocation margin                    "This is the amount of MW that is added to the capacity of the c…
#> 6 A06   Final adjustment margin value                  "This is the margin that is manually added or subtracted to the …