Skip to contents

List area types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

area_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 2 rows and 3 columns.

Examples

head(entsoeapi::area_types)
#> # A tibble: 2 × 3
#>   code  title              description                                                                                  
#>   <chr> <chr>              <chr>                                                                                        
#> 1 A01   Bidding Zone       A Bidding Zone (BZ) is the largest geographical area within which market participants are ab…
#> 2 A02   Metering Grid Area A Metering Grid Area (MGA) is a physical area where consumption, production and exchange can…