Skip to contents

List asset types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

asset_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 90 rows and 3 columns.

Examples

head(entsoeapi::asset_types)
#> # A tibble: 6 × 3
#>   code  title                   description                                                                             
#>   <chr> <chr>                   <chr>                                                                                   
#> 1 A01   Tie line                A high voltage line used for cross border energy interconnections.                      
#> 2 A02   Line                    A specific electric line within a country.                                              
#> 3 A03   Resource Object         A resource that can either produce or consume energy.                                   
#> 4 A04   Generation              A resource that can produce energy.                                                     
#> 5 A05   Load                    A resource that can consume energy.                                                     
#> 6 A06   Phase Shift Transformer An electrical device for controlling the power flow through specific lines in a power t…