Skip to contents

List business types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

business_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 293 rows and 3 columns.

Examples

head(entsoeapi::business_types)
#> # A tibble: 6 × 3
#>   code  title                                    description                                                            
#>   <chr> <chr>                                    <chr>                                                                  
#> 1 A01   Production                               The nature of the business being described is production details.      
#> 2 A02   Internal trade                           The nature of the business being described is internal trade details.  
#> 3 A03   External trade explicit capacity         The nature of the business being described is external trade details b…
#> 4 A04   Consumption                              The nature of the business being described is consumption details.     
#> 5 A05   External trade total                     The nature of the business being described is external trade total.    
#> 6 A06   External trade without explicit capacity The nature of the business being described is external trade details b…