Skip to contents

List coding scheme types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

coding_scheme_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 51 rows and 3 columns.

Examples

head(entsoeapi::coding_scheme_types)
#> # A tibble: 6 × 3
#>   code  title                                      description                                                          
#>   <chr> <chr>                                      <chr>                                                                
#> 1 A01   EIC                                        The coding scheme is the Energy Identification Coding Scheme (EIC), …
#> 2 A02   CGM                                        The coding scheme used for Common Grid Model Exchange Standard (CGME…
#> 3 A03   ISO                                        The coding scheme for the preceding attribute is a code maintained b…
#> 4 A10   Coding scheme which are part of GS1 system The coding schemes maintained by GS1.                                
#> 5 NAD   Andorra National coding scheme             The National coding scheme of the country in question.               
#> 6 NAL   Albania National coding scheme             The National coding scheme of the country in question.