Skip to contents

List contract types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

contract_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 16 rows and 3 columns.

Examples

head(entsoeapi::contract_types)
#> # A tibble: 6 × 3
#>   code  title              description                                                                                  
#>   <chr> <chr>              <chr>                                                                                        
#> 1 A01   Daily contract     The condition under which capacity is allocated and handled is by daily auction or a daily t…
#> 2 A02   Weekly contract    The condition under which capacity is allocated and handled is by weekly auction or a weekly…
#> 3 A03   Monthly contract   The condition under which capacity is allocated and handled is by monthly auction or a month…
#> 4 A04   Yearly contract    The condition under which capacity is allocated and handled is by yearly auction or a yearly…
#> 5 A05   Total contract     This is the sum of all capacity contract types for the period covered.                       
#> 6 A06   Long term contract The condition under which capacity is allocated and handled is by long term trade agreements…