Skip to contents

List coordinate system types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

coordinate_system_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 4 rows and 3 columns.

Examples

head(entsoeapi::coordinate_system_types)
#> # A tibble: 4 × 3
#>   code  title  description                                                                                              
#>   <chr> <chr>  <chr>                                                                                                    
#> 1 A01   ED50   ED 50 (European Datum 1950) is a geodetic datum which was defined after World War II for the internation…
#> 2 A02   OSGB36 Ordinance Survey Great Britain 1936. The Ordinance Survey (OS) devised the national grid reference syste…
#> 3 A03   WGS84  The World Geodetic System version 1984. for use in cartography, geodesy, and navigation including by GPS…
#> 4 A04   GTRF   Galileo Terrestrial Reference Frame