Skip to contents

List curve types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

curve_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 5 rows and 3 columns.

Examples

head(entsoeapi::curve_types)
#> # A tibble: 5 × 3
#>   code  title                       description                                                                         
#>   <chr> <chr>                       <chr>                                                                               
#> 1 A01   Sequential fixed size block The curve is made of successive Intervals of time (Blocks) of constant duration (si…
#> 2 A02   Point                       The curve is made of successive instants of time (Points).                          
#> 3 A03   Variable sized Block        The curve is made of successive Intervals of time (Blocks) of variable duration (si…
#> 4 A04   Overlapping breakpoint      The curve is made of successive Intervals of time of variable duration (size), wher…
#> 5 A05   Non-overlapping breakpoint  This curve is a restriction of the curve type A04, i.e. overlapping breakpoints. Th…