Skip to contents

List customer types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

customer_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 4 rows and 3 columns.

Examples

head(entsoeapi::customer_types)
#> # A tibble: 4 × 3
#>   code  title                       description                                                                         
#>   <chr> <chr>                       <chr>                                                                               
#> 1 A01   Household customer          The customer is a household customer.                                               
#> 2 A02   Deceased household customer The customer is a deceased household customer. May be used for handling an estate o…
#> 3 A03   Company customer            The customer is a company customer.                                                 
#> 4 A04   Estate company customer     The customer is an estate company customer. May be used when a company customer is …