Skip to contents

List direction types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

direction_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 4 rows and 3 columns.

Examples

head(entsoeapi::direction_types)
#> # A tibble: 4 × 3
#>   code  title       description                                                                                   
#>   <chr> <chr>       <chr>                                                                                         
#> 1 A01   UP          Up signifies that the available power can be used by the Purchasing area to increase energy.  
#> 2 A02   DOWN        Down signifies that the available power can be used by the Purchasing area to decrease energy.
#> 3 A03   UP and DOWN Up and Down signifies that the UP and Down values are equal.                                  
#> 4 A04   Stable      The direction at a given instant in time is considered to be stable.