Skip to contents

List document types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

document_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 103 rows and 3 columns.

Examples

head(entsoeapi::document_types)
#> # A tibble: 6 × 3
#>   code  title                             description                                                                   
#>   <chr> <chr>                             <chr>                                                                         
#> 1 A01   Balance responsible schedule      A schedule which has been prepared by a balance responsible party providing p…
#> 2 A02   Allocated capacity schedule       A schedule which has been prepared by a capacity allocator providing allocate…
#> 3 A03   Balance area schedule             A schedule that provides the planned schedule information for a balance area. 
#> 4 A04   System Operator area schedule     A compilation of all external schedules concerning two System Operator areas …
#> 5 A05   Control block area schedule       A compilation of all the exchange programs of all control areas for one contr…
#> 6 A06   Coordination center area schedule A compilation of the exchange programs of all exchange blocks divided into UC…