Skip to contents

List energy product types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

energy_product_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 9 rows and 3 columns.

Examples

head(entsoeapi::energy_product_types)
#> # A tibble: 6 × 3
#>   code          title                     description                                                                   
#>   <chr>         <chr>                     <chr>                                                                         
#> 1 8716867000016 Active power              The product of voltage and the in-phase component of alternating current meas…
#> 2 8716867000023 Reactive power            The product of voltage and current and the sine of the phase angle between th…
#> 3 8716867000030 Active energy             The electrical energy produced, flowing or supplied by an electrical circuit …
#> 4 8716867000047 Reactive energy           The integral with respect to time of reactive power (not used for planned sch…
#> 5 8716867000115 Capacitive reactive power Capacitive reactive power.                                                    
#> 6 8716867000122 Inductive reactive power  Inductive reactive power.