Skip to contents

List flow commodity types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

flow_commodity_option_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 4 rows and 3 columns.

Examples

head(entsoeapi::flow_commodity_option_types)
#> # A tibble: 4 × 3
#>   code  title       description                                                                                         
#>   <chr> <chr>       <chr>                                                                                               
#> 1 E17   Consumption The coded identification of the type of entity, e.g. consumption metering point.                    
#> 2 E18   Production  The coded identification of the type of entity, e.g. production metering point.                     
#> 3 E19   Combined    The coded identification of the type of entity, e.g. combined consumption and production metering p…
#> 4 E20   Exchange    The coded identification of the type of entity, e.g. exchange metering point.