Skip to contents

List fuel types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

fuel_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 55 rows and 3 columns.

Examples

head(entsoeapi::fuel_types)
#> # A tibble: 6 × 3
#>   code  title                                           description                                                     
#>   <chr> <chr>                                           <chr>                                                           
#> 1 A01   Unspecified                                     Fuel that cannot be associated with any of available fuel codes.
#> 2 A02   Renewable solid unspecified                     Fuel produced in a solid form from renewable resources that can…
#> 3 A03   Renewable solid municipal waste                 Solid waste of biological material produced by households, hosp…
#> 4 A04   Renewable solid industrial and commercial waste Solid waste generated by businesses, production units, bureaus …
#> 5 A05   Renewable solid wood                            Solid wood energy resource.                                     
#> 6 A06   Renewable solid animal fats                     Solid animal fats energy resource.