Skip to contents

List grid agreement types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

grid_agreement_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 4 rows and 3 columns.

Examples

head(entsoeapi::grid_agreement_types)
#> # A tibble: 4 × 3
#>   code  title                                                                                  description              
#>   <chr> <chr>                                                                                  <chr>                    
#> 1 E01   Grid usage contract directly between Grid Access Provider and Customer                 The grid usage contract …
#> 2 E02   Grid usage contract  directly between Energy Supplier and Grid Access Provider         The grid usage contract …
#> 3 E03   Grid usage contract  between Grid Access Provider and Customer through Energy Supplier The grid usage contract …
#> 4 E04   No grid usage contract                                                                 There is no grid usage c…