It is defined as equal to the actual sum of power generated by plants on both TSO/DSO networks, from which is deduced:
the balance (export-import) of exchanges on interconnections between neighbouring bidding zones
the power absorbed by energy storage resources
Usage
load_actual_total(
eic = NULL,
period_start = ymd(Sys.Date() - days(x = 1L), tz = "CET"),
period_end = ymd(Sys.Date(), tz = "CET"),
tidy_output = TRUE,
security_token = Sys.getenv("ENTSOE_PAT")
)Arguments
- eic
Energy Identification Code of the bidding zone/country/control area
- period_start
POSIXct or YYYY-MM-DD HH:MM:SS format One year range limit applies
- period_end
POSIXct or YYYY-MM-DD HH:MM:SS format One year range limit applies
- tidy_output
Defaults to TRUE. If TRUE, then flatten nested tables.
- security_token
Security token for ENTSO-E transparency platform
Value
A tibble::tibble() with the queried data.
Examples
# German average daily load.
df <- entsoeapi::load_actual_total(
eic = "10Y1001A1001A83F",
period_start = lubridate::ymd(x = Sys.Date() -
lubridate::days(x = 30), tz = "CET"),
period_end = lubridate::ymd(x = Sys.Date(), tz = "CET"),
tidy_output = TRUE
)
#>
#> ── API call ────────────────────────────────────────────────────────────────────────────────────────────────────────────
#> → https://web-api.tp.entsoe.eu/api?documentType=A65&processType=A16&outBiddingZone_Domain=10Y1001A1001A83F&periodStart=202603132300&periodEnd=202604122200&securityToken=<...>
#> <- HTTP/2 200
#> <- date: Mon, 13 Apr 2026 08:51:55 GMT
#> <- content-type: text/xml
#> <- content-disposition: inline; filename="Actual Total Load_202603132300-202604122200.xml"
#> <- x-content-type-options: nosniff
#> <- x-xss-protection: 0
#> <- vary: accept-encoding
#> <- content-encoding: gzip
#> <- strict-transport-security: max-age=15724800; includeSubDomains
#> <-
#> ✔ response has arrived
#> ✔ Additional type names have been added!
#> ✔ Additional eic names have been added!
#> ✔ Additional definitions have been added!
dplyr::glimpse(df)
#> Rows: 2,876
#> Columns: 21
#> $ ts_out_bidding_zone_domain_mrid <chr> "10Y1001A1001A83F", "10Y1001A1001A83F", "10Y1001A1001A83F", "10Y1001A1001A83F"…
#> $ ts_out_bidding_zone_domain_name <chr> "Germany", "Germany", "Germany", "Germany", "Germany", "Germany", "Germany", "…
#> $ type <chr> "A65", "A65", "A65", "A65", "A65", "A65", "A65", "A65", "A65", "A65", "A65", "…
#> $ type_def <chr> "System total load", "System total load", "System total load", "System total l…
#> $ process_type <chr> "A16", "A16", "A16", "A16", "A16", "A16", "A16", "A16", "A16", "A16", "A16", "…
#> $ process_type_def <chr> "Realised", "Realised", "Realised", "Realised", "Realised", "Realised", "Reali…
#> $ ts_object_aggregation <chr> "A01", "A01", "A01", "A01", "A01", "A01", "A01", "A01", "A01", "A01", "A01", "…
#> $ ts_object_aggregation_def <chr> "Area", "Area", "Area", "Area", "Area", "Area", "Area", "Area", "Area", "Area"…
#> $ ts_business_type <chr> "A04", "A04", "A04", "A04", "A04", "A04", "A04", "A04", "A04", "A04", "A04", "…
#> $ ts_business_type_def <chr> "Consumption", "Consumption", "Consumption", "Consumption", "Consumption", "Co…
#> $ created_date_time <dttm> 2026-04-13 08:51:55, 2026-04-13 08:51:55, 2026-04-13 08:51:55, 2026-04-13 08:…
#> $ revision_number <dbl> 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, …
#> $ time_period_time_interval_start <dttm> 2026-03-13 23:00:00, 2026-03-13 23:00:00, 2026-03-13 23:00:00, 2026-03-13 23:…
#> $ time_period_time_interval_end <dttm> 2026-04-12 22:00:00, 2026-04-12 22:00:00, 2026-04-12 22:00:00, 2026-04-12 22:…
#> $ ts_resolution <chr> "PT15M", "PT15M", "PT15M", "PT15M", "PT15M", "PT15M", "PT15M", "PT15M", "PT15M…
#> $ ts_time_interval_start <dttm> 2026-03-13 23:00:00, 2026-03-13 23:00:00, 2026-03-13 23:00:00, 2026-03-13 23:…
#> $ ts_time_interval_end <dttm> 2026-04-12 22:00:00, 2026-04-12 22:00:00, 2026-04-12 22:00:00, 2026-04-12 22:…
#> $ ts_mrid <dbl> 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, …
#> $ ts_point_dt_start <dttm> 2026-03-13 23:00:00, 2026-03-13 23:15:00, 2026-03-13 23:30:00, 2026-03-13 23:…
#> $ ts_point_quantity <dbl> 46350.38, 46530.27, 46737.13, 46200.95, 44966.11, 44762.38, 44379.48, 44458.06…
#> $ ts_quantity_measure_unit_name <chr> "MAW", "MAW", "MAW", "MAW", "MAW", "MAW", "MAW", "MAW", "MAW", "MAW", "MAW", "…