Skip to contents

Netted and exchanged balancing energy volumes on a specific border. Covers imbalance netting (3.10), aFRR exchange (3.16), and mFRR exchange (3.17) per border between an acquiring and a connecting domain.

Usage

netted_volumes_per_border(
  acquiring_eic = NULL,
  connecting_eic = NULL,
  process_type = NULL,
  period_start = ymd(Sys.Date() - days(x = 7L), tz = "CET"),
  period_end = ymd(Sys.Date(), tz = "CET"),
  tidy_output = TRUE,
  security_token = Sys.getenv("ENTSOE_PAT")
)

Arguments

acquiring_eic

Energy Identification Code of the acquiring area

connecting_eic

Energy Identification Code of the connecting area

process_type

type of balancing process "A51" aFRR "A60" mFRR with scheduled activation "A61" mFRR with direct activation "A63" Imbalance Netting

period_start

POSIXct or YYYY-MM-DD HH:MM:SS format One day range limit applies

period_end

POSIXct or YYYY-MM-DD HH:MM:SS format One day range limit applies

tidy_output

Defaults to TRUE. flatten nested tables

security_token

Security token for ENTSO-E transparency platform

Value

A tibble::tibble() with the queried data.

Examples

if (FALSE) { # \dontrun{
df <- entsoeapi::netted_volumes_per_border(
  acquiring_eic = "10YBE----------2",
  connecting_eic = "10YFR-RTE------C",
  process_type = "A63",
  period_start = lubridate::ymd(x = "2025-03-01", tz = "CET"),
  period_end = lubridate::ymd(x = "2025-03-02", tz = "CET"),
  tidy_output = TRUE
)

dplyr::glimpse(df)
} # }