Skip to contents

List payment terms types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

payment_terms_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 3 rows and 3 columns.

Examples

head(entsoeapi::payment_terms_types)
#> # A tibble: 3 × 3
#>   code  title            description                                                                  
#>   <chr> <chr>            <chr>                                                                        
#> 1 A01   Pay as bid       The amount to be paid shall correspond to the amount bid.                    
#> 2 A02   Pay as cleared   The amount to be paid shall correspond to the amount calculated for clearing.
#> 3 A03   No payment terms There are no payment terms to be used.