Skip to contents

List price category types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

price_category_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 8 rows and 3 columns.

Examples

head(entsoeapi::price_category_types)
#> # A tibble: 6 × 3
#>   code  title                description                                         
#>   <chr> <chr>                <chr>                                               
#> 1 A01   Category 1           A category one price calculation is to be applied.  
#> 2 A02   Category 2           A category two price calculation is to be applied.  
#> 3 A03   Category 3           A category three price calculation is to be applied.
#> 4 A04   Excess balance       The category concerns excess balance.               
#> 5 A05   Insufficient balance A category concerns insufficient balance.           
#> 6 A06   Average bid price    The average bid price for a given product.