Skip to contents

List price component types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

price_component_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 3 rows and 3 columns.

Examples

head(entsoeapi::price_component_types)
#> # A tibble: 3 × 3
#>   code  title                description                                                                        
#>   <chr> <chr>                <chr>                                                                              
#> 1 A01   Scarcity             A scarcity component to be used in nationally defined scarcity situations.         
#> 2 A02   Incentive            An incentive component to be used to fulfil nationally defined boundary conditions.
#> 3 A03   Financial neutrality A component related to the financial neutrality of the connecting TSO.