Skip to contents

List price direction types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

price_direction_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 2 rows and 3 columns.

Examples

head(entsoeapi::price_direction_types)
#> # A tibble: 2 × 3
#>   code  title        description                                                                              
#>   <chr> <chr>        <chr>                                                                                    
#> 1 A01   Expenditure. Expenditure, i.e. the Impacted Area System Operator pays to the internal Market Parties. 
#> 2 A02   Income.      Income, i.e. The Impacted Area System Operator receives from the internal Market Parties.