Skip to contents

List process types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

process_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 75 rows and 3 columns.

Examples

head(entsoeapi::process_types)
#> # A tibble: 6 × 3
#>   code  title                    description                                                                            
#>   <chr> <chr>                    <chr>                                                                                  
#> 1 A01   Day ahead                The information provided concerns a day ahead process.                                 
#> 2 A02   Intra day incremental    The information provided concerns an intra day schedule.                               
#> 3 A03   Inter-area transit       The information provided concerns an inter area transit schedule. The rules governing …
#> 4 A04   System operation closure The information provided concerns the closure of a given period of both scheduled and …
#> 5 A05   Metered data aggregation The information provided concerns the aggregation process of metered information.      
#> 6 A06   Imbalance settlement     The information provided concerns the imbalance settlement for a given period for a ba…