Skip to contents

List quality types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

quality_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 7 rows and 3 columns.

Examples

head(entsoeapi::quality_types)
#> # A tibble: 6 × 3
#>   code  title         description                                                                                       
#>   <chr> <chr>         <chr>                                                                                             
#> 1 A01   Adjusted      The contents of the object have been adjusted.                                                    
#> 2 A02   Not available The contents of the object are not available.                                                     
#> 3 A03   Estimated     The contents of the object are estimated. The code is typically used when measured values are mis…
#> 4 A04   As provided   The contents of the object are as provided.                                                       
#> 5 A05   Incomplete    The contents of the object are calculated based on incomplete data.                               
#> 6 A06   Calculated    The contents of the object are calculated. The code is typically used when a value is calculated …