Skip to contents

List reason code types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

reason_code_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 166 rows and 3 columns.

Examples

head(entsoeapi::reason_code_types)
#> # A tibble: 6 × 3
#>   code  title                                               description                                                 
#>   <chr> <chr>                                               <chr>                                                       
#> 1 999   "Errors not specifically identified "               This code is used to identify errors that have not been spe…
#> 2 A01   "Message fully accepted"                            The message has been fully accepted for application process…
#> 3 A02   "Message fully rejected "                           No part of the message has been accepted for application pr…
#> 4 A03   "Message contains errors at the time series level " Part of the message contents, i.e. certain time series, has…
#> 5 A04   "Time interval incorrect "                          The schedule time interval is not within the contractual ag…
#> 6 A05   "Sender without valid contract "                    The sender has no current valid contract with the TSO. The …