Skip to contents

List rights types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

rights_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 6 rows and 3 columns.

Examples

head(entsoeapi::rights_types)
#> # A tibble: 6 × 3
#>   code  title                           description                                     
#>   <chr> <chr>                           <chr>                                           
#> 1 A01   Use It Or Lose It               Any rights not nominated shall be lost.         
#> 2 A02   Use It Or Sell It               Any rights that are not nominated shall be sold.
#> 3 A03   Allocation curtailment possible Rights acquired may be curtailed.               
#> 4 A04   Nomination curtailment possible Rights acquired may be curtailed at nomination. 
#> 5 A05   Resale possible                 Acquired rights may be resold.                  
#> 6 A06   Transfer possible               Acquired rights may be transferred.