Skip to contents

List unit of measure types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

unit_of_measure_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 33 rows and 3 columns.

Examples

head(entsoeapi::unit_of_measure_types)
#> # A tibble: 6 × 3
#>   code  title       description                                                                                         
#>   <chr> <chr>       <chr>                                                                                               
#> 1 A59   OKTA unit   A unit of measurement of the cloudiness expressed in OKTA or OCTA, i.e. A unit of count defining th…
#> 2 A90   gigawatt    GW unit as per UN/CEFACT recommendation 20.                                                         
#> 3 A97   hectopascal A unit of measurement of the pressure expressed in hectopascal.                                     
#> 4 AMP   ampere      The unit of electrical current in the International system of Units (SI) equivalent to one Coulomb …
#> 5 C62   One         A unit for dimensionless quantities, also called quantities of dimension one.                       
#> 6 CEL   Celsius     A unit of measurement of temperature expressed in degree Celsius.