Skip to contents

List unit symbol types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

unit_symbol_types

Format

An object of class tbl_df (inherits from tbl, data.frame) with 11 rows and 3 columns.

Examples

head(entsoeapi::unit_symbol_types)
#> # A tibble: 6 × 3
#>   code  title                   description                                                                             
#>   <chr> <chr>                   <chr>                                                                                   
#> 1 AMP   Ampere                  The unit of electrical current in the International system of Units (SI) equivalent to …
#> 2 C62   One                     A unit for dimensionless quantities, also called quantities of dimension one.           
#> 3 DD    degree (unit of angle)  A unit of measurement of angles expressed in a 0 to 360 degree gradient.                
#> 4 GKH   grams per kilowatt hour It represents the mass rate of emissions per unit of work accomplished.                 
#> 5 HTZ   Hertz                   HTZ unit as per UN/CEFACT recommendation 20                                             
#> 6 KVT   kV                      The symbol of kV