List allocation mode types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'
Source:R/data.R
allocation_mode_types.RdList allocation mode types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'
See also
Other types:
analog_types,
area_types,
asset_types,
auction_types,
business_types,
category_types,
classification_types,
coding_scheme_types,
connection_category_types,
contract_types,
coordinate_system_types,
currency_types,
curve_types,
customer_types,
direction_types,
document_types,
eic_types,
energy_product_types,
flow_commodity_option_types,
fuel_types,
grid_agreement_types,
hvdc_mode_types,
indicator_types,
market_product_types,
message_types,
object_aggregation_types,
payment_terms_types,
price_category_types,
price_component_types,
price_direction_types,
process_types,
quality_types,
reason_code_types,
rights_types,
role_types,
settlement_method_types,
status_types,
sub_area_types,
tariff_types,
timeframe_types,
unit_multiplier,
unit_of_measure_types,
unit_symbol_types
Examples
head(entsoeapi::allocation_mode_types)
#> # A tibble: 4 × 3
#> code title description
#> <chr> <chr> <chr>
#> 1 A01 Order by price with pro rata The allocation method is by price with eventual pro rata.
#> 2 A02 Order by price with first come - first served The allocation method is by price with eventual use of first come…
#> 3 A03 First come - First served The allocation method is first come first served.
#> 4 A04 Pro rata The allocation method is pro rata.