List analog types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'
Source:R/data.R
analog_types.RdList analog types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'
See also
Other types:
allocation_mode_types,
area_types,
asset_types,
auction_types,
business_types,
category_types,
classification_types,
coding_scheme_types,
connection_category_types,
contract_types,
coordinate_system_types,
currency_types,
curve_types,
customer_types,
direction_types,
document_types,
eic_types,
energy_product_types,
flow_commodity_option_types,
fuel_types,
grid_agreement_types,
hvdc_mode_types,
indicator_types,
market_product_types,
message_types,
object_aggregation_types,
payment_terms_types,
price_category_types,
price_component_types,
price_direction_types,
process_types,
quality_types,
reason_code_types,
rights_types,
role_types,
settlement_method_types,
status_types,
sub_area_types,
tariff_types,
timeframe_types,
unit_multiplier,
unit_of_measure_types,
unit_symbol_types
Examples
head(entsoeapi::analog_types)
#> # A tibble: 6 × 3
#> code title description
#> <chr> <chr> <chr>
#> 1 A01 Flow "This is the computed flow for the monitored element in the cons…
#> 2 A02 Permanent admissible transmission limit (PATL) "The permanent load of transmission system elements which is all…
#> 3 A03 Flow reliability margin "This is the flow reliability margin for a given critical networ…
#> 4 A04 Spanning margin value "This is the margin that is taken into account when spanning (fa…
#> 5 A05 Long term allocation margin "This is the amount of MW that is added to the capacity of the c…
#> 6 A06 Final adjustment margin value "This is the margin that is manually added or subtracted to the …