List contract types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'
Source:R/data.R
contract_types.RdList contract types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'
See also
Other types:
allocation_mode_types,
analog_types,
area_types,
asset_types,
auction_types,
business_types,
category_types,
classification_types,
coding_scheme_types,
connection_category_types,
coordinate_system_types,
currency_types,
curve_types,
customer_types,
direction_types,
document_types,
eic_types,
energy_product_types,
flow_commodity_option_types,
fuel_types,
grid_agreement_types,
hvdc_mode_types,
indicator_types,
market_product_types,
message_types,
object_aggregation_types,
payment_terms_types,
price_category_types,
price_component_types,
price_direction_types,
process_types,
quality_types,
reason_code_types,
rights_types,
role_types,
settlement_method_types,
status_types,
sub_area_types,
tariff_types,
timeframe_types,
unit_multiplier,
unit_of_measure_types,
unit_symbol_types
Examples
head(entsoeapi::contract_types)
#> # A tibble: 6 × 3
#> code title description
#> <chr> <chr> <chr>
#> 1 A01 Daily contract The condition under which capacity is allocated and handled is by daily auction or a daily t…
#> 2 A02 Weekly contract The condition under which capacity is allocated and handled is by weekly auction or a weekly…
#> 3 A03 Monthly contract The condition under which capacity is allocated and handled is by monthly auction or a month…
#> 4 A04 Yearly contract The condition under which capacity is allocated and handled is by yearly auction or a yearly…
#> 5 A05 Total contract This is the sum of all capacity contract types for the period covered.
#> 6 A06 Long term contract The condition under which capacity is allocated and handled is by long term trade agreements…