List curve types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'
Source:R/data.R
curve_types.RdList curve types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'
See also
Other types:
allocation_mode_types,
analog_types,
area_types,
asset_types,
auction_types,
business_types,
category_types,
classification_types,
coding_scheme_types,
connection_category_types,
contract_types,
coordinate_system_types,
currency_types,
customer_types,
direction_types,
document_types,
eic_types,
energy_product_types,
flow_commodity_option_types,
fuel_types,
grid_agreement_types,
hvdc_mode_types,
indicator_types,
market_product_types,
message_types,
object_aggregation_types,
payment_terms_types,
price_category_types,
price_component_types,
price_direction_types,
process_types,
quality_types,
reason_code_types,
rights_types,
role_types,
settlement_method_types,
status_types,
sub_area_types,
tariff_types,
timeframe_types,
unit_multiplier,
unit_of_measure_types,
unit_symbol_types
Examples
head(entsoeapi::curve_types)
#> # A tibble: 5 × 3
#> code title description
#> <chr> <chr> <chr>
#> 1 A01 Sequential fixed size block The curve is made of successive Intervals of time (Blocks) of constant duration (si…
#> 2 A02 Point The curve is made of successive instants of time (Points).
#> 3 A03 Variable sized Block The curve is made of successive Intervals of time (Blocks) of variable duration (si…
#> 4 A04 Overlapping breakpoint The curve is made of successive Intervals of time of variable duration (size), wher…
#> 5 A05 Non-overlapping breakpoint This curve is a restriction of the curve type A04, i.e. overlapping breakpoints. Th…