List direction types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'
Source:R/data.R
direction_types.RdList direction types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'
See also
Other types:
allocation_mode_types,
analog_types,
area_types,
asset_types,
auction_types,
business_types,
category_types,
classification_types,
coding_scheme_types,
connection_category_types,
contract_types,
coordinate_system_types,
currency_types,
curve_types,
customer_types,
document_types,
eic_types,
energy_product_types,
flow_commodity_option_types,
fuel_types,
grid_agreement_types,
hvdc_mode_types,
indicator_types,
market_product_types,
message_types,
object_aggregation_types,
payment_terms_types,
price_category_types,
price_component_types,
price_direction_types,
process_types,
quality_types,
reason_code_types,
rights_types,
role_types,
settlement_method_types,
status_types,
sub_area_types,
tariff_types,
timeframe_types,
unit_multiplier,
unit_of_measure_types,
unit_symbol_types
Examples
head(entsoeapi::direction_types)
#> # A tibble: 4 × 3
#> code title description
#> <chr> <chr> <chr>
#> 1 A01 UP Up signifies that the available power can be used by the Purchasing area to increase energy.
#> 2 A02 DOWN Down signifies that the available power can be used by the Purchasing area to decrease energy.
#> 3 A03 UP and DOWN Up and Down signifies that the UP and Down values are equal.
#> 4 A04 Stable The direction at a given instant in time is considered to be stable.