List document types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'
Source:R/data.R
document_types.RdList document types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'
See also
Other types:
allocation_mode_types,
analog_types,
area_types,
asset_types,
auction_types,
business_types,
category_types,
classification_types,
coding_scheme_types,
connection_category_types,
contract_types,
coordinate_system_types,
currency_types,
curve_types,
customer_types,
direction_types,
eic_types,
energy_product_types,
flow_commodity_option_types,
fuel_types,
grid_agreement_types,
hvdc_mode_types,
indicator_types,
market_product_types,
message_types,
object_aggregation_types,
payment_terms_types,
price_category_types,
price_component_types,
price_direction_types,
process_types,
quality_types,
reason_code_types,
rights_types,
role_types,
settlement_method_types,
status_types,
sub_area_types,
tariff_types,
timeframe_types,
unit_multiplier,
unit_of_measure_types,
unit_symbol_types
Examples
head(entsoeapi::document_types)
#> # A tibble: 6 × 3
#> code title description
#> <chr> <chr> <chr>
#> 1 A01 Balance responsible schedule A schedule which has been prepared by a balance responsible party providing p…
#> 2 A02 Allocated capacity schedule A schedule which has been prepared by a capacity allocator providing allocate…
#> 3 A03 Balance area schedule A schedule that provides the planned schedule information for a balance area.
#> 4 A04 System Operator area schedule A compilation of all external schedules concerning two System Operator areas …
#> 5 A05 Control block area schedule A compilation of all the exchange programs of all control areas for one contr…
#> 6 A06 Coordination center area schedule A compilation of the exchange programs of all exchange blocks divided into UC…