List energy product types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'
Source:R/data.R
energy_product_types.RdList energy product types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'
See also
Other types:
allocation_mode_types,
analog_types,
area_types,
asset_types,
auction_types,
business_types,
category_types,
classification_types,
coding_scheme_types,
connection_category_types,
contract_types,
coordinate_system_types,
currency_types,
curve_types,
customer_types,
direction_types,
document_types,
eic_types,
flow_commodity_option_types,
fuel_types,
grid_agreement_types,
hvdc_mode_types,
indicator_types,
market_product_types,
message_types,
object_aggregation_types,
payment_terms_types,
price_category_types,
price_component_types,
price_direction_types,
process_types,
quality_types,
reason_code_types,
rights_types,
role_types,
settlement_method_types,
status_types,
sub_area_types,
tariff_types,
timeframe_types,
unit_multiplier,
unit_of_measure_types,
unit_symbol_types
Examples
head(entsoeapi::energy_product_types)
#> # A tibble: 6 × 3
#> code title description
#> <chr> <chr> <chr>
#> 1 8716867000016 Active power The product of voltage and the in-phase component of alternating current meas…
#> 2 8716867000023 Reactive power The product of voltage and current and the sine of the phase angle between th…
#> 3 8716867000030 Active energy The electrical energy produced, flowing or supplied by an electrical circuit …
#> 4 8716867000047 Reactive energy The integral with respect to time of reactive power (not used for planned sch…
#> 5 8716867000115 Capacitive reactive power Capacitive reactive power.
#> 6 8716867000122 Inductive reactive power Inductive reactive power.