The net position informs whether the given area imports or exports energy. Those rows which hold the queried eic value in the 'ts_connecting_domain_mrid' column show the export value. Those rows which hold the queried eic value in the 'ts_acquiring_domain_mrid' column show the import value.
Arguments
- eic
Energy Identification Code of the area
- process_type
type of frequency restoration reserve "A51" aFRR "A60" mFRR with scheduled activation "A61" mFRR with direct activation
- period_start
POSIXct or YYYY-MM-DD HH:MM:SS format One day range limit applies
- period_end
POSIXct or YYYY-MM-DD HH:MM:SS format One day range limit applies
- tidy_output
Defaults to TRUE. flatten nested tables
- security_token
Security token for ENTSO-E transparency platform
Examples
df1 <- entsoeapi::exchanged_volumes(
eic = "10YCZ-CEPS-----N",
process_type = "A51",
period_start = lubridate::ymd(x = "2022-08-16", tz = "CET"),
period_end = lubridate::ymd(x = "2022-08-17", tz = "CET"),
tidy_output = TRUE
)
#>
#> ── API call ────────────────────────────────────────────────────────────────────────────────────────────────────────────
#> → https://web-api.tp.entsoe.eu/api?documentType=B17&processType=A51&Acquiring_domain=10YCZ-CEPS-----N&Connecting_Domain=10YCZ-CEPS-----N&periodStart=202208152200&periodEnd=202208162200&securityToken=<...>
#> <- HTTP/2 200
#> <- date: Thu, 05 Mar 2026 16:12:14 GMT
#> <- content-type: application/zip
#> <- content-length: 179306
#> <- content-disposition: attachment; filename="Netted and Exchanged Volumes [IFs IN 3.10, mFRR 3.17, aFRR 3.16]_202208152200-202208162200.zip"
#> <- x-content-type-options: nosniff
#> <- x-xss-protection: 0
#> <- strict-transport-security: max-age=15724800; includeSubDomains
#> <-
#> ✔ response has arrived
#> ✔ /tmp/RtmpksiKAO/001-NETTED_AND_EXCHANGED_VOLUMES_202208152200-202208162200.xml has been read in
str(df1)
#> tibble [43,200 × 23] (S3: tbl_df/tbl/data.frame)
#> $ area_domain_mrid : chr [1:43200] "10Y1001C--00090V" "10Y1001C--00090V" "10Y1001C--00090V" "10Y1001C--00090V" ...
#> $ area_domain_name : chr [1:43200] "aFRR Region" "aFRR Region" "aFRR Region" "aFRR Region" ...
#> $ ts_connecting_domain_mrid : chr [1:43200] "10YCZ-CEPS-----N" "10YCZ-CEPS-----N" "10YCZ-CEPS-----N" "10YCZ-CEPS-----N" ...
#> $ ts_connecting_domain_name : chr [1:43200] "Czech Republic" "Czech Republic" "Czech Republic" "Czech Republic" ...
#> $ ts_acquiring_domain_mrid : chr [1:43200] "10Y1001C--00090V" "10Y1001C--00090V" "10Y1001C--00090V" "10Y1001C--00090V" ...
#> $ ts_acquiring_domain_name : chr [1:43200] "aFRR Region" "aFRR Region" "aFRR Region" "aFRR Region" ...
#> $ doc_status_value : chr [1:43200] "A02" "A02" "A02" "A02" ...
#> $ doc_status : chr [1:43200] "Allocated capacity schedule" "Allocated capacity schedule" "Allocated capacity schedule" "Allocated capacity schedule" ...
#> $ type : chr [1:43200] "B17" "B17" "B17" "B17" ...
#> $ type_def : chr [1:43200] "Aggregated netted external TSO schedule document" "Aggregated netted external TSO schedule document" "Aggregated netted external TSO schedule document" "Aggregated netted external TSO schedule document" ...
#> $ process_type : chr [1:43200] "A51" "A51" "A51" "A51" ...
#> $ process_type_def : chr [1:43200] "Automatic frequency restoration reserve" "Automatic frequency restoration reserve" "Automatic frequency restoration reserve" "Automatic frequency restoration reserve" ...
#> $ ts_business_type : chr [1:43200] "B09" "B09" "B09" "B09" ...
#> $ ts_business_type_def : chr [1:43200] "Net position" "Net position" "Net position" "Net position" ...
#> $ created_date_time : POSIXct[1:43200], format: "2026-03-05 16:12:14" "2026-03-05 16:12:14" "2026-03-05 16:12:14" "2026-03-05 16:12:14" ...
#> $ revision_number : num [1:43200] 1 1 1 1 1 1 1 1 1 1 ...
#> $ ts_resolution : chr [1:43200] "PT4S" "PT4S" "PT4S" "PT4S" ...
#> $ ts_time_interval_start : POSIXct[1:43200], format: "2022-08-15 22:00:00" "2022-08-15 22:00:00" "2022-08-15 22:00:00" "2022-08-15 22:00:00" ...
#> $ ts_time_interval_end : POSIXct[1:43200], format: "2022-08-16 22:00:00" "2022-08-16 22:00:00" "2022-08-16 22:00:00" "2022-08-16 22:00:00" ...
#> $ ts_mrid : num [1:43200] 1 1 1 1 1 1 1 1 1 1 ...
#> $ ts_point_dt_start : POSIXct[1:43200], format: "2022-08-15 22:00:00" "2022-08-15 22:00:04" "2022-08-15 22:00:08" "2022-08-15 22:00:12" ...
#> $ ts_point_quantity : num [1:43200] 0.0011 0.0011 0 0 0 0 0 0.004 0.0098 0.0105 ...
#> $ ts_quantity_measure_unit_name: chr [1:43200] "MWH" "MWH" "MWH" "MWH" ...
df2 <- entsoeapi::exchanged_volumes(
eic = "10YCZ-CEPS-----N",
process_type = "A60",
period_start = lubridate::ymd(x = "2024-07-11", tz = "CET"),
period_end = lubridate::ymd(x = "2024-07-12", tz = "CET"),
tidy_output = TRUE
)
#>
#> ── API call ────────────────────────────────────────────────────────────────────────────────────────────────────────────
#> → https://web-api.tp.entsoe.eu/api?documentType=B17&processType=A60&Acquiring_domain=10YCZ-CEPS-----N&Connecting_Domain=10YCZ-CEPS-----N&periodStart=202407102200&periodEnd=202407112200&securityToken=<...>
#> <- HTTP/2 200
#> <- date: Thu, 05 Mar 2026 16:12:25 GMT
#> <- content-type: application/zip
#> <- content-length: 1174
#> <- content-disposition: attachment; filename="Netted and Exchanged Volumes [IFs IN 3.10, mFRR 3.17, aFRR 3.16]_202407102200-202407112200.zip"
#> <- x-content-type-options: nosniff
#> <- x-xss-protection: 0
#> <- strict-transport-security: max-age=15724800; includeSubDomains
#> <-
#> ✔ response has arrived
#> ✔ /tmp/RtmpksiKAO/001-NETTED_AND_EXCHANGED_VOLUMES_202407102200-202407112200.xml has been read in
#> ℹ No additional definitions added!
str(df2)
#> tibble [96 × 21] (S3: tbl_df/tbl/data.frame)
#> $ area_domain_mrid : chr [1:96] "10Y1001C--00085O" "10Y1001C--00085O" "10Y1001C--00085O" "10Y1001C--00085O" ...
#> $ area_domain_name : chr [1:96] "mFRR region" "mFRR region" "mFRR region" "mFRR region" ...
#> $ ts_connecting_domain_mrid : chr [1:96] "10Y1001C--00085O" "10Y1001C--00085O" "10Y1001C--00085O" "10Y1001C--00085O" ...
#> $ ts_connecting_domain_name : chr [1:96] "mFRR region" "mFRR region" "mFRR region" "mFRR region" ...
#> $ ts_acquiring_domain_mrid : chr [1:96] "10YCZ-CEPS-----N" "10YCZ-CEPS-----N" "10YCZ-CEPS-----N" "10YCZ-CEPS-----N" ...
#> $ ts_acquiring_domain_name : chr [1:96] "Czech Republic" "Czech Republic" "Czech Republic" "Czech Republic" ...
#> $ type : chr [1:96] "B17" "B17" "B17" "B17" ...
#> $ type_def : chr [1:96] "Aggregated netted external TSO schedule document" "Aggregated netted external TSO schedule document" "Aggregated netted external TSO schedule document" "Aggregated netted external TSO schedule document" ...
#> $ process_type : chr [1:96] "A60" "A60" "A60" "A60" ...
#> $ process_type_def : chr [1:96] "Scheduled activation mFRR" "Scheduled activation mFRR" "Scheduled activation mFRR" "Scheduled activation mFRR" ...
#> $ ts_business_type : chr [1:96] "B09" "B09" "B09" "B09" ...
#> $ ts_business_type_def : chr [1:96] "Net position" "Net position" "Net position" "Net position" ...
#> $ created_date_time : POSIXct[1:96], format: "2026-03-05 16:12:25" "2026-03-05 16:12:25" "2026-03-05 16:12:25" "2026-03-05 16:12:25" ...
#> $ revision_number : num [1:96] 1 1 1 1 1 1 1 1 1 1 ...
#> $ ts_resolution : chr [1:96] "PT15M" "PT15M" "PT15M" "PT15M" ...
#> $ ts_time_interval_start : POSIXct[1:96], format: "2024-07-10 22:00:00" "2024-07-10 22:00:00" "2024-07-10 22:00:00" "2024-07-10 22:00:00" ...
#> $ ts_time_interval_end : POSIXct[1:96], format: "2024-07-11 22:00:00" "2024-07-11 22:00:00" "2024-07-11 22:00:00" "2024-07-11 22:00:00" ...
#> $ ts_mrid : num [1:96] 1 1 1 1 1 1 1 1 1 1 ...
#> $ ts_point_dt_start : POSIXct[1:96], format: "2024-07-10 22:00:00" "2024-07-10 22:15:00" "2024-07-10 22:30:00" "2024-07-10 22:45:00" ...
#> $ ts_point_quantity : num [1:96] 0 0 0 0 0 0 0 0 0 0 ...
#> $ ts_quantity_measure_unit_name: chr [1:96] "MWH" "MWH" "MWH" "MWH" ...