Skip to contents

List grid agreement types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'

Usage

grid_agreement_types

Format

An object of class data.table (inherits from data.frame) with 4 rows and 3 columns.

Examples

dplyr::glimpse(entsoeapi::grid_agreement_types)
#> Rows: 4
#> Columns: 3
#> $ code        <chr> "E01", "E02", "E03", "E04"
#> $ title       <chr> "Grid usage contract directly between Grid Access Provider and Customer", "Grid usage contract  di…
#> $ description <chr> "The grid usage contract is a contract directly between the grid access provider and the customer.…