It is defined as equal to the actual sum of power generated by plants on both TSO/DSO networks, from which is deduced:
the balance (export-import) of exchanges on interconnections between neighbouring bidding zones
the power absorbed by energy storage resources
Arguments
- eic
Energy Identification Code of the bidding zone/country/control area
- period_start
POSIXct or YYYY-MM-DD HH:MM:SS format One year range limit applies
- period_end
POSIXct or YYYY-MM-DD HH:MM:SS format One year range limit applies
- tidy_output
Defaults to TRUE. If TRUE, then flatten nested tables.
- security_token
Security token for ENTSO-E transparency platform
Examples
# German average daily load.
df <- entsoeapi::load_actual_total(
eic = "10Y1001A1001A83F",
period_start = lubridate::ymd(x = Sys.Date() -
lubridate::days(x = 30), tz = "CET"),
period_end = lubridate::ymd(x = Sys.Date(), tz = "CET"),
tidy_output = TRUE
)
#>
#> ── API call ────────────────────────────────────────────────────────────────────────────────────────────────────────────
#> → https://web-api.tp.entsoe.eu/api?documentType=A65&processType=A16&outBiddingZone_Domain=10Y1001A1001A83F&periodStart=202602022300&periodEnd=202603042300&securityToken=<...>
#> <- HTTP/2 200
#> <- date: Thu, 05 Mar 2026 16:12:55 GMT
#> <- content-type: text/xml
#> <- content-disposition: inline; filename="Actual Total Load_202602022300-202603042300.xml"
#> <- x-content-type-options: nosniff
#> <- x-xss-protection: 0
#> <- vary: accept-encoding
#> <- content-encoding: gzip
#> <- strict-transport-security: max-age=15724800; includeSubDomains
#> <-
#> ✔ response has arrived
str(df)
#> tibble [2,880 × 21] (S3: tbl_df/tbl/data.frame)
#> $ ts_out_bidding_zone_domain_mrid: chr [1:2880] "10Y1001A1001A83F" "10Y1001A1001A83F" "10Y1001A1001A83F" "10Y1001A1001A83F" ...
#> $ ts_out_bidding_zone_domain_name: chr [1:2880] "Germany" "Germany" "Germany" "Germany" ...
#> $ type : chr [1:2880] "A65" "A65" "A65" "A65" ...
#> $ type_def : chr [1:2880] "System total load" "System total load" "System total load" "System total load" ...
#> $ process_type : chr [1:2880] "A16" "A16" "A16" "A16" ...
#> $ process_type_def : chr [1:2880] "Realised" "Realised" "Realised" "Realised" ...
#> $ ts_object_aggregation : chr [1:2880] "A01" "A01" "A01" "A01" ...
#> $ ts_object_aggregation_def : chr [1:2880] "Area" "Area" "Area" "Area" ...
#> $ ts_business_type : chr [1:2880] "A04" "A04" "A04" "A04" ...
#> $ ts_business_type_def : chr [1:2880] "Consumption" "Consumption" "Consumption" "Consumption" ...
#> $ created_date_time : POSIXct[1:2880], format: "2026-03-05 16:12:55" "2026-03-05 16:12:55" "2026-03-05 16:12:55" "2026-03-05 16:12:55" ...
#> $ revision_number : num [1:2880] 1 1 1 1 1 1 1 1 1 1 ...
#> $ time_period_time_interval_start: POSIXct[1:2880], format: "2026-02-02 23:00:00" "2026-02-02 23:00:00" "2026-02-02 23:00:00" "2026-02-02 23:00:00" ...
#> $ time_period_time_interval_end : POSIXct[1:2880], format: "2026-03-04 23:00:00" "2026-03-04 23:00:00" "2026-03-04 23:00:00" "2026-03-04 23:00:00" ...
#> $ ts_resolution : chr [1:2880] "PT15M" "PT15M" "PT15M" "PT15M" ...
#> $ ts_time_interval_start : POSIXct[1:2880], format: "2026-02-02 23:00:00" "2026-02-02 23:00:00" "2026-02-02 23:00:00" "2026-02-02 23:00:00" ...
#> $ ts_time_interval_end : POSIXct[1:2880], format: "2026-03-04 23:00:00" "2026-03-04 23:00:00" "2026-03-04 23:00:00" "2026-03-04 23:00:00" ...
#> $ ts_mrid : num [1:2880] 1 1 1 1 1 1 1 1 1 1 ...
#> $ ts_point_dt_start : POSIXct[1:2880], format: "2026-02-02 23:00:00" "2026-02-02 23:15:00" "2026-02-02 23:30:00" "2026-02-02 23:45:00" ...
#> $ ts_point_quantity : num [1:2880] 57682 57053 56603 56047 55501 ...
#> $ ts_quantity_measure_unit_name : chr [1:2880] "MAW" "MAW" "MAW" "MAW" ...