Get Netted & Exchanged Volumes Per Border (IFs 3.10, 3.16 & 3.17)
Source:R/en_balancing.R
netted_volumes_per_border.RdNetted and exchanged balancing energy volumes on a specific border. Covers imbalance netting (3.10), aFRR exchange (3.16), and mFRR exchange (3.17) per border between an acquiring and a connecting domain.
Usage
netted_volumes_per_border(
acquiring_eic = NULL,
connecting_eic = NULL,
process_type = NULL,
period_start = ymd(Sys.Date() - days(x = 7L), tz = "CET"),
period_end = ymd(Sys.Date(), tz = "CET"),
tidy_output = TRUE,
security_token = Sys.getenv("ENTSOE_PAT")
)Arguments
- acquiring_eic
Energy Identification Code of the acquiring area
- connecting_eic
Energy Identification Code of the connecting area
- process_type
type of balancing process "A51" aFRR "A60" mFRR with scheduled activation "A61" mFRR with direct activation "A63" Imbalance Netting
- period_start
POSIXct or YYYY-MM-DD HH:MM:SS format One day range limit applies
- period_end
POSIXct or YYYY-MM-DD HH:MM:SS format One day range limit applies
- tidy_output
Defaults to TRUE. flatten nested tables
- security_token
Security token for ENTSO-E transparency platform
Value
A tibble::tibble() with the queried data.
See also
Other balancing endpoints:
activated_balancing_prices(),
aggregated_balancing_energy_bids(),
allocation_of_cross_zonal_balancing_cap(),
balancing_border_cap_limit(),
balancing_energy_bids(),
changes_to_bid_availability(),
contracted_reserves(),
current_balancing_state(),
elastic_demands(),
exchanged_volumes(),
exchanged_volumes_per_border(),
fcr_total_capacity(),
financial_expenses_and_income(),
hvdc_link_constrains(),
imbalance_prices(),
imbalance_volumes(),
netted_volumes(),
procured_balancing_capacity(),
rr_and_frr_actual_capacity(),
shares_of_fcr_capacity(),
sharing_of_rr_and_frr_capacity()
Examples
if (FALSE) { # \dontrun{
df <- entsoeapi::netted_volumes_per_border(
acquiring_eic = "10YBE----------2",
connecting_eic = "10YFR-RTE------C",
process_type = "A63",
period_start = lubridate::ymd(x = "2025-03-01", tz = "CET"),
period_end = lubridate::ymd(x = "2025-03-02", tz = "CET"),
tidy_output = TRUE
)
dplyr::glimpse(df)
} # }