List reason code types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'
Source:R/data.R
reason_code_types.RdList reason code types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'
See also
Other types:
allocation_mode_types,
analog_types,
area_types,
asset_types,
auction_types,
business_types,
category_types,
classification_types,
coding_scheme_types,
connection_category_types,
contract_types,
coordinate_system_types,
currency_types,
curve_types,
customer_types,
direction_types,
document_types,
eic_types,
energy_product_types,
flow_commodity_option_types,
fuel_types,
grid_agreement_types,
hvdc_mode_types,
indicator_types,
market_product_types,
message_types,
object_aggregation_types,
payment_terms_types,
price_category_types,
price_component_types,
price_direction_types,
process_types,
quality_types,
rights_types,
role_types,
settlement_method_types,
status_types,
sub_area_types,
tariff_types,
timeframe_types,
unit_multiplier,
unit_of_measure_types,
unit_symbol_types
Examples
head(entsoeapi::reason_code_types)
#> # A tibble: 6 × 3
#> code title description
#> <chr> <chr> <chr>
#> 1 999 "Errors not specifically identified " This code is used to identify errors that have not been spe…
#> 2 A01 "Message fully accepted" The message has been fully accepted for application process…
#> 3 A02 "Message fully rejected " No part of the message has been accepted for application pr…
#> 4 A03 "Message contains errors at the time series level " Part of the message contents, i.e. certain time series, has…
#> 5 A04 "Time interval incorrect " The schedule time interval is not within the contractual ag…
#> 6 A05 "Sender without valid contract " The sender has no current valid contract with the TSO. The …