List unit symbol types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'
Source:R/data.R
unit_symbol_types.RdList unit symbol types based on 'https://www.entsoe.eu/Documents/EDI/Library/CodelistV94.zip'
See also
Other types:
allocation_mode_types,
analog_types,
area_types,
asset_types,
auction_types,
business_types,
category_types,
classification_types,
coding_scheme_types,
connection_category_types,
contract_types,
coordinate_system_types,
currency_types,
curve_types,
customer_types,
direction_types,
document_types,
eic_types,
energy_product_types,
flow_commodity_option_types,
fuel_types,
grid_agreement_types,
hvdc_mode_types,
indicator_types,
market_product_types,
message_types,
object_aggregation_types,
payment_terms_types,
price_category_types,
price_component_types,
price_direction_types,
process_types,
quality_types,
reason_code_types,
rights_types,
role_types,
settlement_method_types,
status_types,
sub_area_types,
tariff_types,
timeframe_types,
unit_multiplier,
unit_of_measure_types
Examples
head(entsoeapi::unit_symbol_types)
#> # A tibble: 6 × 3
#> code title description
#> <chr> <chr> <chr>
#> 1 AMP Ampere The unit of electrical current in the International system of Units (SI) equivalent to …
#> 2 C62 One A unit for dimensionless quantities, also called quantities of dimension one.
#> 3 DD degree (unit of angle) A unit of measurement of angles expressed in a 0 to 360 degree gradient.
#> 4 GKH grams per kilowatt hour It represents the mass rate of emissions per unit of work accomplished.
#> 5 HTZ Hertz HTZ unit as per UN/CEFACT recommendation 20
#> 6 KVT kV The symbol of kV